Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(120)

Unified Diff: chrome/browser/metrics/chrome_metrics_service_client.h

Issue 2009773007: Add AntiVirus information to the system profile. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: hash the product name and version Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/metrics/chrome_metrics_service_client.h
diff --git a/chrome/browser/metrics/chrome_metrics_service_client.h b/chrome/browser/metrics/chrome_metrics_service_client.h
index b340c84bb2ce773c96ac50735a4184e67cca4051..cb2e9fd6c6221b9f2dd78b7e4d2f0f08da77fc3d 100644
--- a/chrome/browser/metrics/chrome_metrics_service_client.h
+++ b/chrome/browser/metrics/chrome_metrics_service_client.h
@@ -33,6 +33,7 @@ class SigninStatusMetricsProvider;
#endif
namespace metrics {
+class AntiVirusMetricsProvider;
class DriveMetricsProvider;
class MetricsService;
class MetricsStateManager;
@@ -103,9 +104,13 @@ class ChromeMetricsServiceClient
void OnInitTaskGotPluginInfo();
// Called after GoogleUpdate init task has been completed that continues the
// init task by loading drive metrics.
void OnInitTaskGotGoogleUpdateData();
+ // Called after AntiVirus init task has been completed that continues the
+ // init task by loading drive metrics.
+ void OnInitTaskGotAntiVirusData();
+
// Called after the drive metrics init task has been completed that continues
// the init task by loading profiler data.
void OnInitTaskGotDriveMetrics();
@@ -190,6 +195,10 @@ class ChromeMetricsServiceClient
// The GoogleUpdateMetricsProviderWin instance that was registered with
// MetricsService. Has the same lifetime as |metrics_service_|.
GoogleUpdateMetricsProviderWin* google_update_metrics_provider_;
+
+ // The AntiVirusMetricsProvider instance that was registered with
+ // MetricsService. Has the same lifetime as |metrics_service_|.
+ metrics::AntiVirusMetricsProvider* antivirus_metrics_provider_;
#endif
// The DriveMetricsProvider instance that was registered with MetricsService.
@@ -103,9 +104,13 @@ class ChromeMetricsServiceClient
void OnInitTaskGotPluginInfo();
// Called after GoogleUpdate init task has been completed that continues the
- // init task by loading drive metrics.
+ // init task by loading AntiVirus metrics.
void OnInitTaskGotGoogleUpdateData();

Powered by Google App Engine
This is Rietveld 408576698